==> pinot-common-0.12.1-sources.jar: org/apache/pinot/common/proto/PinotQueryWorkerGrpc.java <==
package org.apache.pinot.common.proto;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.41.0)",
    comments = "Source: worker.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class PinotQueryWorkerGrpc {

  private PinotQueryWorkerGrpc() {}

  public static final String SERVICE_NAME = "org.apache.pinot.common.proto.PinotQueryWorker";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<org.apache.pinot.common.proto.Worker.QueryRequest,
      org.apache.pinot.common.proto.Worker.QueryResponse> getSubmitMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Submit",
      requestType = org.apache.pinot.common.proto.Worker.QueryRequest.class,
      responseType = org.apache.pinot.common.proto.Worker.QueryResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<org.apache.pinot.common.proto.Worker.QueryRequest,
      org.apache.pinot.common.proto.Worker.QueryResponse> getSubmitMethod() {
    io.grpc.MethodDescriptor<org.apache.pinot.common.proto.Worker.QueryRequest, org.apache.pinot.common.proto.Worker.QueryResponse> getSubmitMethod;
    if ((getSubmitMethod = PinotQueryWorkerGrpc.getSubmitMethod) == null) {
      synchronized (PinotQueryWorkerGrpc.class) {
        if ((getSubmitMethod = PinotQueryWorkerGrpc.getSubmitMethod) == null) {
          PinotQueryWorkerGrpc.getSubmitMethod = getSubmitMethod =
              io.grpc.MethodDescriptor.<org.apache.pinot.common.proto.Worker.QueryRequest, org.apache.pinot.common.proto.Worker.QueryResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Submit"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  org.apache.pinot.common.proto.Worker.QueryRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  org.apache.pinot.common.proto.Worker.QueryResponse.getDefaultInstance()))
              .setSchemaDescriptor(new PinotQueryWorkerMethodDescriptorSupplier("Submit"))
              .build();
        }
      }
    }
    return getSubmitMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static PinotQueryWorkerStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<PinotQueryWorkerStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<PinotQueryWorkerStub>() {
        @java.lang.Override
        public PinotQueryWorkerStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new PinotQueryWorkerStub(channel, callOptions);
        }
      };
    return PinotQueryWorkerStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static PinotQueryWorkerBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<PinotQueryWorkerBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<PinotQueryWorkerBlockingStub>() {
        @java.lang.Override
        public PinotQueryWorkerBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new PinotQueryWorkerBlockingStub(channel, callOptions);
        }
      };
    return PinotQueryWorkerBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static PinotQueryWorkerFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<PinotQueryWorkerFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<PinotQueryWorkerFutureStub>() {
        @java.lang.Override
        public PinotQueryWorkerFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new PinotQueryWorkerFutureStub(channel, callOptions);
        }
      };
    return PinotQueryWorkerFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class PinotQueryWorkerImplBase implements io.grpc.BindableService {

    /**
     * <pre>
     * Dispatch a QueryRequest to a PinotQueryWorker
     * </pre>
     */
    public void submit(org.apache.pinot.common.proto.Worker.QueryRequest request,
        io.grpc.stub.StreamObserver<org.apache.pinot.common.proto.Worker.QueryResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getSubmitMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getSubmitMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                org.apache.pinot.common.proto.Worker.QueryRequest,
                org.apache.pinot.common.proto.Worker.QueryResponse>(
                  this, METHODID_SUBMIT)))
          .build();
    }
  }

  /**
   */
  public static final class PinotQueryWorkerStub extends io.grpc.stub.AbstractAsyncStub<PinotQueryWorkerStub> {
    private PinotQueryWorkerStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PinotQueryWorkerStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new PinotQueryWorkerStub(channel, callOptions);
    }

    /**
     * <pre>
     * Dispatch a QueryRequest to a PinotQueryWorker
     * </pre>
     */
    public void submit(org.apache.pinot.common.proto.Worker.QueryRequest request,
        io.grpc.stub.StreamObserver<org.apache.pinot.common.proto.Worker.QueryResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getSubmitMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class PinotQueryWorkerBlockingStub extends io.grpc.stub.AbstractBlockingStub<PinotQueryWorkerBlockingStub> {
    private PinotQueryWorkerBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PinotQueryWorkerBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new PinotQueryWorkerBlockingStub(channel, callOptions);
    }

    /**
     * <pre>
     * Dispatch a QueryRequest to a PinotQueryWorker
     * </pre>
     */
    public org.apache.pinot.common.proto.Worker.QueryResponse submit(org.apache.pinot.common.proto.Worker.QueryRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getSubmitMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class PinotQueryWorkerFutureStub extends io.grpc.stub.AbstractFutureStub<PinotQueryWorkerFutureStub> {
    private PinotQueryWorkerFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PinotQueryWorkerFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new PinotQueryWorkerFutureStub(channel, callOptions);
    }

    /**
     * <pre>
     * Dispatch a QueryRequest to a PinotQueryWorker
     * </pre>
     */
    public com.google.common.util.concurrent.ListenableFuture<org.apache.pinot.common.proto.Worker.QueryResponse> submit(
        org.apache.pinot.common.proto.Worker.QueryRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getSubmitMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_SUBMIT = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final PinotQueryWorkerImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(PinotQueryWorkerImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_SUBMIT:
          serviceImpl.submit((org.apache.pinot.common.proto.Worker.QueryRequest) request,
              (io.grpc.stub.StreamObserver<org.apache.pinot.common.proto.Worker.QueryResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class PinotQueryWorkerBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    PinotQueryWorkerBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return org.apache.pinot.common.proto.Worker.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("PinotQueryWorker");
    }
  }

  private static final class PinotQueryWorkerFileDescriptorSupplier
      extends PinotQueryWorkerBaseDescriptorSupplier {
    PinotQueryWorkerFileDescriptorSupplier() {}
  }

  private static final class PinotQueryWorkerMethodDescriptorSupplier
      extends PinotQueryWorkerBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    PinotQueryWorkerMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (PinotQueryWorkerGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new PinotQueryWorkerFileDescriptorSupplier())
              .addMethod(getSubmitMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> pinot-common-1.0.0-sources.jar: org/apache/pinot/common/proto/PinotQueryWorkerGrpc.java <==
package org.apache.pinot.common.proto;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.53.0)",
    comments = "Source: worker.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class PinotQueryWorkerGrpc {

  private PinotQueryWorkerGrpc() {}

  public static final String SERVICE_NAME = "org.apache.pinot.common.proto.PinotQueryWorker";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<org.apache.pinot.common.proto.Worker.QueryRequest,
      org.apache.pinot.common.proto.Worker.QueryResponse> getSubmitMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Submit",
      requestType = org.apache.pinot.common.proto.Worker.QueryRequest.class,
      responseType = org.apache.pinot.common.proto.Worker.QueryResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<org.apache.pinot.common.proto.Worker.QueryRequest,
      org.apache.pinot.common.proto.Worker.QueryResponse> getSubmitMethod() {
    io.grpc.MethodDescriptor<org.apache.pinot.common.proto.Worker.QueryRequest, org.apache.pinot.common.proto.Worker.QueryResponse> getSubmitMethod;
    if ((getSubmitMethod = PinotQueryWorkerGrpc.getSubmitMethod) == null) {
      synchronized (PinotQueryWorkerGrpc.class) {
        if ((getSubmitMethod = PinotQueryWorkerGrpc.getSubmitMethod) == null) {
          PinotQueryWorkerGrpc.getSubmitMethod = getSubmitMethod =
              io.grpc.MethodDescriptor.<org.apache.pinot.common.proto.Worker.QueryRequest, org.apache.pinot.common.proto.Worker.QueryResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Submit"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  org.apache.pinot.common.proto.Worker.QueryRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  org.apache.pinot.common.proto.Worker.QueryResponse.getDefaultInstance()))
              .setSchemaDescriptor(new PinotQueryWorkerMethodDescriptorSupplier("Submit"))
              .build();
        }
      }
    }
    return getSubmitMethod;
  }

  private static volatile io.grpc.MethodDescriptor<org.apache.pinot.common.proto.Worker.CancelRequest,
      org.apache.pinot.common.proto.Worker.CancelResponse> getCancelMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Cancel",
      requestType = org.apache.pinot.common.proto.Worker.CancelRequest.class,
      responseType = org.apache.pinot.common.proto.Worker.CancelResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<org.apache.pinot.common.proto.Worker.CancelRequest,
      org.apache.pinot.common.proto.Worker.CancelResponse> getCancelMethod() {
    io.grpc.MethodDescriptor<org.apache.pinot.common.proto.Worker.CancelRequest, org.apache.pinot.common.proto.Worker.CancelResponse> getCancelMethod;
    if ((getCancelMethod = PinotQueryWorkerGrpc.getCancelMethod) == null) {
      synchronized (PinotQueryWorkerGrpc.class) {
        if ((getCancelMethod = PinotQueryWorkerGrpc.getCancelMethod) == null) {
          PinotQueryWorkerGrpc.getCancelMethod = getCancelMethod =
              io.grpc.MethodDescriptor.<org.apache.pinot.common.proto.Worker.CancelRequest, org.apache.pinot.common.proto.Worker.CancelResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Cancel"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  org.apache.pinot.common.proto.Worker.CancelRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  org.apache.pinot.common.proto.Worker.CancelResponse.getDefaultInstance()))
              .setSchemaDescriptor(new PinotQueryWorkerMethodDescriptorSupplier("Cancel"))
              .build();
        }
      }
    }
    return getCancelMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static PinotQueryWorkerStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<PinotQueryWorkerStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<PinotQueryWorkerStub>() {
        @java.lang.Override
        public PinotQueryWorkerStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new PinotQueryWorkerStub(channel, callOptions);
        }
      };
    return PinotQueryWorkerStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static PinotQueryWorkerBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<PinotQueryWorkerBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<PinotQueryWorkerBlockingStub>() {
        @java.lang.Override
        public PinotQueryWorkerBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new PinotQueryWorkerBlockingStub(channel, callOptions);
        }
      };
    return PinotQueryWorkerBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static PinotQueryWorkerFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<PinotQueryWorkerFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<PinotQueryWorkerFutureStub>() {
        @java.lang.Override
        public PinotQueryWorkerFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new PinotQueryWorkerFutureStub(channel, callOptions);
        }
      };
    return PinotQueryWorkerFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class PinotQueryWorkerImplBase implements io.grpc.BindableService {

    /**
     * <pre>
     * Dispatch a QueryRequest to a PinotQueryWorker
     * </pre>
     */
    public void submit(org.apache.pinot.common.proto.Worker.QueryRequest request,
        io.grpc.stub.StreamObserver<org.apache.pinot.common.proto.Worker.QueryResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getSubmitMethod(), responseObserver);
    }

    /**
     */
    public void cancel(org.apache.pinot.common.proto.Worker.CancelRequest request,
        io.grpc.stub.StreamObserver<org.apache.pinot.common.proto.Worker.CancelResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getCancelMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getSubmitMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                org.apache.pinot.common.proto.Worker.QueryRequest,
                org.apache.pinot.common.proto.Worker.QueryResponse>(
                  this, METHODID_SUBMIT)))
          .addMethod(
            getCancelMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                org.apache.pinot.common.proto.Worker.CancelRequest,
                org.apache.pinot.common.proto.Worker.CancelResponse>(
                  this, METHODID_CANCEL)))
          .build();
    }
  }

  /**
   */
  public static final class PinotQueryWorkerStub extends io.grpc.stub.AbstractAsyncStub<PinotQueryWorkerStub> {
    private PinotQueryWorkerStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PinotQueryWorkerStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new PinotQueryWorkerStub(channel, callOptions);
    }

    /**
     * <pre>
     * Dispatch a QueryRequest to a PinotQueryWorker
     * </pre>
     */
    public void submit(org.apache.pinot.common.proto.Worker.QueryRequest request,
        io.grpc.stub.StreamObserver<org.apache.pinot.common.proto.Worker.QueryResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getSubmitMethod(), getCallOptions()), request, responseObserver);
    }

    /**
     */
    public void cancel(org.apache.pinot.common.proto.Worker.CancelRequest request,
        io.grpc.stub.StreamObserver<org.apache.pinot.common.proto.Worker.CancelResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getCancelMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class PinotQueryWorkerBlockingStub extends io.grpc.stub.AbstractBlockingStub<PinotQueryWorkerBlockingStub> {
    private PinotQueryWorkerBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PinotQueryWorkerBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new PinotQueryWorkerBlockingStub(channel, callOptions);
    }

    /**
     * <pre>
     * Dispatch a QueryRequest to a PinotQueryWorker
     * </pre>
     */
    public org.apache.pinot.common.proto.Worker.QueryResponse submit(org.apache.pinot.common.proto.Worker.QueryRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getSubmitMethod(), getCallOptions(), request);
    }

    /**
     */
    public org.apache.pinot.common.proto.Worker.CancelResponse cancel(org.apache.pinot.common.proto.Worker.CancelRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getCancelMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class PinotQueryWorkerFutureStub extends io.grpc.stub.AbstractFutureStub<PinotQueryWorkerFutureStub> {
    private PinotQueryWorkerFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PinotQueryWorkerFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new PinotQueryWorkerFutureStub(channel, callOptions);
    }

    /**
     * <pre>
     * Dispatch a QueryRequest to a PinotQueryWorker
     * </pre>
     */
    public com.google.common.util.concurrent.ListenableFuture<org.apache.pinot.common.proto.Worker.QueryResponse> submit(
        org.apache.pinot.common.proto.Worker.QueryRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getSubmitMethod(), getCallOptions()), request);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<org.apache.pinot.common.proto.Worker.CancelResponse> cancel(
        org.apache.pinot.common.proto.Worker.CancelRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getCancelMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_SUBMIT = 0;
  private static final int METHODID_CANCEL = 1;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final PinotQueryWorkerImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(PinotQueryWorkerImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_SUBMIT:
          serviceImpl.submit((org.apache.pinot.common.proto.Worker.QueryRequest) request,
              (io.grpc.stub.StreamObserver<org.apache.pinot.common.proto.Worker.QueryResponse>) responseObserver);
          break;
        case METHODID_CANCEL:
          serviceImpl.cancel((org.apache.pinot.common.proto.Worker.CancelRequest) request,
              (io.grpc.stub.StreamObserver<org.apache.pinot.common.proto.Worker.CancelResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class PinotQueryWorkerBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    PinotQueryWorkerBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return org.apache.pinot.common.proto.Worker.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("PinotQueryWorker");
    }
  }

  private static final class PinotQueryWorkerFileDescriptorSupplier
      extends PinotQueryWorkerBaseDescriptorSupplier {
    PinotQueryWorkerFileDescriptorSupplier() {}
  }

  private static final class PinotQueryWorkerMethodDescriptorSupplier
      extends PinotQueryWorkerBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    PinotQueryWorkerMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (PinotQueryWorkerGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new PinotQueryWorkerFileDescriptorSupplier())
              .addMethod(getSubmitMethod())
              .addMethod(getCancelMethod())
              .build();
        }
      }
    }
    return result;
  }
}
